tests: add regression tests for Follow TCP Stream
[metze/wireshark/wip.git] / extcap.h
index d066d9d2a9e25a5fc7b622a8b9320ff7b7c13cb4..386955dd617a72205ab5e8298ae407736feb52a4 100644 (file)
--- a/extcap.h
+++ b/extcap.h
@@ -6,19 +6,7 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef __EXTCAP_H__
@@ -29,7 +17,6 @@
 #include <glib.h>
 
 #ifdef _WIN32
-#include <windows.h>
 #include <wsutil/unicode-utils.h>
 #endif
 
 
 /* Prefix for the pipe interfaces */
 #define EXTCAP_PIPE_PREFIX "wireshark_extcap"
+#define EXTCAP_CONTROL_IN_PREFIX  "wireshark_control_ext_to_ws"
+#define EXTCAP_CONTROL_OUT_PREFIX "wireshark_control_ws_to_ext"
 
 #define EXTCAP_ARGUMENT_CONFIG                  "--extcap-config"
-#define EXTCAP_ARGUMENT_LIST_INTERFACES "--extcap-interfaces"
+#define EXTCAP_ARGUMENT_RELOAD_OPTION           "--extcap-reload-option"
+#define EXTCAP_ARGUMENT_LIST_INTERFACES         "--extcap-interfaces"
 #define EXTCAP_ARGUMENT_INTERFACE               "--extcap-interface"
 #define EXTCAP_ARGUMENT_LIST_DLTS               "--extcap-dlts"
+#define EXTCAP_ARGUMENT_VERSION                 "--extcap-version"
 
 #define EXTCAP_ARGUMENT_RUN_CAPTURE             "--capture"
 #define EXTCAP_ARGUMENT_CAPTURE_FILTER          "--extcap-capture-filter"
 #define EXTCAP_ARGUMENT_RUN_PIPE                "--fifo"
+#define EXTCAP_ARGUMENT_CONTROL_IN              "--extcap-control-in"
+#define EXTCAP_ARGUMENT_CONTROL_OUT             "--extcap-control-out"
 
 typedef struct _extcap_info {
     gchar * basename;
     gchar * full_path;
     gchar * version;
+    gchar * help;
+
+    GList * interfaces;
 } extcap_info;
 
+typedef enum {
+    EXTCAP_FILTER_UNKNOWN,
+    EXTCAP_FILTER_VALID,
+    EXTCAP_FILTER_INVALID
+} extcap_filter_status;
+
 struct _extcap_arg;
 
 #ifdef __cplusplus
@@ -79,19 +81,49 @@ extcap_get_if_dlts(const gchar * ifname, char ** err_str);
 GList *
 append_extcap_interface_list(GList *list, char **err_str);
 
+extcap_info *
+extcap_get_tool_info(const gchar * toolname);
+
+extcap_info *
+extcap_get_tool_by_ifname(const gchar *ifname);
+
 /* return the help page or NULL for the given ifname */
 gchar *
 extcap_get_help_for_ifname(const char *ifname);
 
/* get a list of all available extcap tools */
 GHashTable *
-extcap_tools_list(void);
+extcap_loaded_interfaces(void);
+
+/* remove all loaded interfaces */
+void
+extcap_clear_interfaces(void);
 
 /* returns the configuration for the given interface name, or an
* empty list, if no configuration has been found */
 GList *
 extcap_get_if_configuration(const char * ifname);
 
+/* returns the configuration values for the given argument, or an
+ * empty list, if no values could been found
+ * @param ifname the interface name
+ * @param argname the name of the argument, for which the values should be retrieved
+ */
+GList *
+extcap_get_if_configuration_values(const char * ifname, const char * argname, GHashTable * arguments);
+
+/**
+ * Check if the capture filter for the given interface name is valid.
+ * @param ifname Interface to check
+ * @param filter Capture filter to check
+ * @param err_str Error string returned if filter is invalid
+ * @return Filter check status.
+ */
+extcap_filter_status
+extcap_verify_capture_filter(const char *ifname, const char *filter, gchar **err_str);
+
 /**
  * Frees the memory from extcap_get_if_configuration.
  * @param list The list returned by extcap_get_if_configuration.
@@ -104,27 +136,22 @@ extcap_free_if_configuration(GList *list, gboolean free_args);
 gboolean
 extcap_has_configuration(const char * ifname, gboolean is_required);
 
-#ifdef WIN32
-HANDLE
-extcap_get_win32_handle();
-#endif
+gboolean
+extcap_has_toolbar(const char *ifname);
 
 gboolean
 extcap_init_interfaces(capture_options * capture_opts);
 
 gboolean
-extcap_create_pipe(char ** fifo);
+extcap_create_pipe(const gchar *ifname, gchar **fifo, const gchar *pipe_prefix);
 
 /* Clean up all if related stuff */
 void
-extcap_if_cleanup(capture_options * capture_opts _U_, gchar ** errormsg);
+extcap_if_cleanup(capture_options * capture_opts, gchar ** errormsg);
 
 struct preference *
 extcap_pref_for_argument(const gchar *ifname, struct _extcap_arg * arg);
 
-void
-extcap_pref_store(struct _extcap_arg * arg, const char * newval);
-
 /* Clean up global extcap stuff on program exit */
 void extcap_cleanup(void);
@@ -79,19 +81,49 @@ extcap_get_if_dlts(const gchar * ifname, char ** err_str);
 extcap_get_help_for_ifname(const char *ifname);
 
-/* get a list of all available extcap tools */
+/* get a list of all available extcap executables and their interfaces */
 GHashTable *
@@ -79,19 +81,49 @@ extcap_get_if_dlts(const gchar * ifname, char ** err_str);
 
 /* returns the configuration for the given interface name, or an
- * empty list, if no configuration has been found */
+ * empty list, if no configuration has been found
+ * @param ifname the interface name
+ */
 GList *
 extcap_get_if_configuration(const char * ifname);